==> jc-1.4.0.tar.gz: soot/grimp/internal/GNewArrayExpr.h <==
// public class soot.grimp.internal.GNewArrayExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1f9d97f08b58d68e soot_grimp_internal_GNewArrayExpr
// @dep_class cc0d5acb5fd5a93a soot_jimple_internal_AbstractNewArrayExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNewArrayExpr

#include "soot/jimple/internal/AbstractNewArrayExpr.h"

#ifndef _JC_soot_grimp_internal_GNewArrayExpr_H_
#define _JC_soot_grimp_internal_GNewArrayExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GNewArrayExpr$sub_refs	_jc_soot_grimp_internal_GNewArrayExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GNewArrayExpr$sub_nonrefs	_jc_soot_grimp_internal_GNewArrayExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GNewArrayExpr$refs	_jc_soot_grimp_internal_GNewArrayExpr$refs;
typedef struct _jc_soot_grimp_internal_GNewArrayExpr$nonrefs	_jc_soot_grimp_internal_GNewArrayExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GNewArrayExpr$object	_jc_soot_grimp_internal_GNewArrayExpr$object;

typedef const struct _jc_soot_grimp_internal_GNewArrayExpr$vmethods	_jc_soot_grimp_internal_GNewArrayExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GNewArrayExpr$vtable	_jc_soot_grimp_internal_GNewArrayExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GNewArrayExpr$vtype	_jc_soot_grimp_internal_GNewArrayExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GNewArrayExpr$method$_init$0b3348c37b519d7f(_jc_env *, struct _jc_soot_grimp_internal_GNewArrayExpr$object *, struct _jc_soot_Type$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GNewArrayExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GNewArrayExpr$object *);
extern jint _jc_soot_grimp_internal_GNewArrayExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GNewArrayExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GNewArrayExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GNewArrayExpr$method_info$getPrecedence$9873747576c8b2e5;

// Virtual methods structure
struct _jc_soot_grimp_internal_GNewArrayExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GNewArrayExpr$object *);
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GNewArrayExpr$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GNewArrayExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractNewArrayExpr$vmethods	soot_jimple_internal_AbstractNewArrayExpr;
	_jc_soot_grimp_internal_GNewArrayExpr$vmethods	soot_grimp_internal_GNewArrayExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GNewArrayExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GNewArrayExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNewArrayExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GNewArrayExpr$refs {
    _jc_soot_grimp_internal_GNewArrayExpr$sub_refs	soot_grimp_internal_GNewArrayExpr;
    _jc_soot_jimple_internal_AbstractNewArrayExpr$sub_refs	soot_jimple_internal_AbstractNewArrayExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNewArrayExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GNewArrayExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractNewArrayExpr$sub_nonrefs	soot_jimple_internal_AbstractNewArrayExpr;
    _jc_soot_grimp_internal_GNewArrayExpr$sub_nonrefs	soot_grimp_internal_GNewArrayExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GNewArrayExpr$object {
	_jc_soot_grimp_internal_GNewArrayExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GNewArrayExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GNewArrayExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GNewArrayExpr$vtype _jc_soot_grimp_internal_GNewArrayExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GNewArrayExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GNewArrayExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GNewArrayExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GNewArrayExpr.h <==
// public class soot.grimp.internal.GNewArrayExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1f9d97f08b58d68e soot_grimp_internal_GNewArrayExpr
// @dep_class cc0d5acb5fd5a93a soot_jimple_internal_AbstractNewArrayExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNewArrayExpr

#include "soot/jimple/internal/AbstractNewArrayExpr.h"

#ifndef _JC_soot_grimp_internal_GNewArrayExpr_H_
#define _JC_soot_grimp_internal_GNewArrayExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GNewArrayExpr$sub_refs	_jc_soot_grimp_internal_GNewArrayExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GNewArrayExpr$sub_nonrefs	_jc_soot_grimp_internal_GNewArrayExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GNewArrayExpr$refs	_jc_soot_grimp_internal_GNewArrayExpr$refs;
typedef struct _jc_soot_grimp_internal_GNewArrayExpr$nonrefs	_jc_soot_grimp_internal_GNewArrayExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GNewArrayExpr$object	_jc_soot_grimp_internal_GNewArrayExpr$object;

typedef const struct _jc_soot_grimp_internal_GNewArrayExpr$vmethods	_jc_soot_grimp_internal_GNewArrayExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GNewArrayExpr$vtable	_jc_soot_grimp_internal_GNewArrayExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GNewArrayExpr$vtype	_jc_soot_grimp_internal_GNewArrayExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GNewArrayExpr$method$_init$0b3348c37b519d7f(_jc_env *, struct _jc_soot_grimp_internal_GNewArrayExpr$object *, struct _jc_soot_Type$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GNewArrayExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GNewArrayExpr$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_grimp_internal_GNewArrayExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GNewArrayExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GNewArrayExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GNewArrayExpr$method_info$getPrecedence$9873747576c8b2e5;

// Virtual methods structure
struct _jc_soot_grimp_internal_GNewArrayExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GNewArrayExpr$object *) _JC_JCNI_ATTR;
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GNewArrayExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GNewArrayExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractNewArrayExpr$vmethods	soot_jimple_internal_AbstractNewArrayExpr;
	_jc_soot_grimp_internal_GNewArrayExpr$vmethods	soot_grimp_internal_GNewArrayExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GNewArrayExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GNewArrayExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNewArrayExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GNewArrayExpr$refs {
    _jc_soot_grimp_internal_GNewArrayExpr$sub_refs	soot_grimp_internal_GNewArrayExpr;
    _jc_soot_jimple_internal_AbstractNewArrayExpr$sub_refs	soot_jimple_internal_AbstractNewArrayExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNewArrayExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GNewArrayExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractNewArrayExpr$sub_nonrefs	soot_jimple_internal_AbstractNewArrayExpr;
    _jc_soot_grimp_internal_GNewArrayExpr$sub_nonrefs	soot_grimp_internal_GNewArrayExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GNewArrayExpr$object {
	_jc_soot_grimp_internal_GNewArrayExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GNewArrayExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GNewArrayExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GNewArrayExpr$vtype _jc_soot_grimp_internal_GNewArrayExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GNewArrayExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GNewArrayExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GNewArrayExpr_H_ */
